# Cion

Cion is a minimal data validation library. It is unopinionated about how you get the input and what you do with the output.

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install cion.

```bash
pip install cion
```

## Usage

View the [examples](/examples) directory and the [tests](/tests) directory for examples on how to use Cion

## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

## License
[MIT](https://choosealicense.com/licenses/mit/)